<?php
/**
 * shale functions and definitions
 *
 * Set up the theme and provides some helper functions, which are used in the
 * theme as custom template tags. Others are attached to action and filter
 * hooks in WordPress to change core functionality.
 *
 * When using a child theme you can override certain functions (those wrapped
 * in a function_exists() call) by defining them first in your child theme's
 * functions.php file. The child theme's functions.php file is included before
 * the parent theme's file, so the child theme functions would be used.
 *
 * @link https://codex.wordpress.org/Theme_Development
 * @link https://codex.wordpress.org/Child_Themes
 *
 * Functions that are not pluggable (not wrapped in function_exists()) are
 * instead attached to a filter or action hook.
 *
 * For more information on hooks, actions, and filters,
 * {@link https://codex.wordpress.org/Plugin_API}
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since shale 1.0
 */
if ( ! isset( $content_width ) ) {
	$content_width = 660;
}

if ( ! function_exists( 'shale_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 *
 * @since shale 1.0
 */
function shale_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 */
	load_theme_textdomain( 'shale', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * See: https://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	// Add custom logo support
	add_theme_support( 'custom-logo' );

	// Add custom header support
	$custom_header_args = array(
		'flex-width'    => true,
		'width'         => 1260,
		'flex-height'   => true,
		'height'        => 200,
		'header-text'   => false,
	);
	add_theme_support( 'custom-header', $custom_header_args );

	// Add custom background support
	add_theme_support( "custom-background" );

	// Add new image sizes
	add_image_size( 'featured-image', 710, 470, array( 'left', 'center' ) );

	// This theme uses wp_nav_menu() in one locations.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'shale' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption'
	) );
}
endif; // shale_setup
add_action( 'after_setup_theme', 'shale_setup' );

/**
 * Register widget area.
 *
 * @since shale 1.0
 *
 * @link https://codex.wordpress.org/Function_Reference/register_sidebar
 */
function shale_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Right Sidebar', 'shale' ),
		'id'            => 'sidebar-right',
		'description'   => __( 'Add widgets here to appear in your sidebar.', 'shale' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
	register_sidebar( array(
		'name'          => __( 'Footer', 'shale' ),
		'id'            => 'sidebar-footer',
		'description'   => __( 'Add widgets here to appear in your footer.', 'shale' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'shale_widgets_init' );

/**
 * JavaScript Detection.
 *
 * Adds a `js` class to the root `<html>` element when JavaScript is detected.
 *
 * @since shale 1.0
 */
function shale_javascript_detection() {
	echo "<script>(function(html){html.className = html.className.replace(/\bno-js\b/,'js')})(document.documentElement);</script>\n";
}
add_action( 'wp_head', 'shale_javascript_detection', 0 );

/**
 * Enqueue scripts and styles.
 *
 * @since shale 1.0
 */
function shale_scripts() {
	
	// Scripts
	wp_enqueue_script( 'shale-modernizr', get_template_directory_uri() . '/assets/js/modernizr-custom.js', array( 'jquery' ), '3.2.0', true );
	wp_enqueue_script( 'fitvids', get_template_directory_uri() . '/assets/js/jquery.fitvids.js', array( 'jquery' ), '1.0.3', true );
  wp_enqueue_script( 'flexslider', get_template_directory_uri() . '/assets/js/jquery.flexslider.js', array( 'jquery' ), '2.6.0', true );	
	wp_enqueue_script( 'shale-shale', get_template_directory_uri() . '/assets/js/shale.js', array( 'jquery' ), '1.0.0', true );	

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

  // Stylesheets
  wp_enqueue_style( 'font-awesome-css', get_template_directory_uri() . '/assets/css/font-awesome.css', false, '4.6.3','all' );
  wp_enqueue_style( 'flexslider-css', get_template_directory_uri() . '/assets/css/flexslider.css', false, '2.6.0','all' );
	wp_enqueue_style( 'shale-css', get_stylesheet_uri() );

}
add_action( 'wp_enqueue_scripts', 'shale_scripts' );

/* Editor Style Sheet */

function shale_add_editor_style() {
    add_editor_style( 'assets/css/custom-editor-style.css' );
}
add_action( 'after_setup_theme', 'shale_add_editor_style' );

/**
 * Add Google Fonts
 */

function shale_add_google_fonts() {
	wp_enqueue_style( 'shale-google-fonts', 'http://fonts.googleapis.com/css?family=Roboto+Condensed:400,700|Roboto:400,700|Open+Sans:700', false ); 
}

add_action( 'wp_enqueue_scripts', 'shale_add_google_fonts' );

/**
 * Add a pingback url auto-discovery header for singularly identifiable articles.
 */
function shale_pingback_header() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">' . "\n", get_bloginfo( 'pingback_url' ) );
	}
}
add_action( 'wp_head', 'shale_pingback_header' );

/** 
 * Remove duplicate posts from main query if slider active
 */

function shale_exclude_slider_posts( $query ) {

	$enabled = get_theme_mod( 'enable_slider' );
	$remove_stickies = get_theme_mod( 'remove_stickies' );

  if ( $enabled && $remove_stickies && $query->is_home() && $query->is_main_query() ) {
  	 $query->set( 'post__not_in', get_option( 'sticky_posts' ) );
  }
}
add_action( 'pre_get_posts', 'shale_exclude_slider_posts' );

/** Add Sidebar Class if Sidebar active */

function shale_body_classes( $classes ) {
    
  if ( is_active_sidebar( 'sidebar-right' ) ) { 
			$classes[] = 'sidebar-right';
	} else {
		 $classes[] = 'no-sidebar-right';
	}
	return $classes;
}
add_filter( 'body_class','shale_body_classes' );

/**
 * Custom template tags for this theme.
 *
 * @since shale 1.0
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom Options.
 *
 * @since shale 1.0
 */
require get_template_directory() . '/inc/customizer.php';